///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// File:	hrc4string.js
// Author:	Copyright (c) 2008 Henk Reints, http://henk-reints.nl
// Purpose:	Add HRC4 methods to String prototype
// Original date: 26-Mar-2008
// Last update:   16-Apr-2008
//
// Prerequisite:
//	The hrc4.js script must be loaded before this script
//
// Description:
//	Prototype methods for the String Object,
//	to let you easily use the various HRC4 methods using Object Oriented Programming.
//
//	NOTE:
//	the cypher, encypher, decypher, encrypt, and decrypt methods accept either a
//	direct key String as argument x or an already existing HRC4 Object Instance.
//	if a key is given then old style KSA is used with the 'init' method of the HRC4 object,
//	if an HRC4 object is given it may of course be initialised either way. 
//
// Example:
//	myString  = "The quick brown fox jumps over a lazy dog."
//	myHash    = myString.MD5()
//	myB64     = myString.toBase64(true)
//
//	myOldHRC4 = new HRC4(thisVarHoldsMyVerySecretKey)	// uses the old init KSA method
//	myNewHRC4 = HRC4.new2(myFirstSecretKey,myOtherSecretKey)// uses the new init2 KSA method
//
//	NOTE: below is 3 times the same method:
//	send: myString.encrypt(myOldHRC4)			// uses the old style HRC4 object
//	send: myString.encrypt(myNewHRC4)			// uses the new style HRC4 object
//	send: myString.encrypt(yetAnotherSecretKey)		// uses a direct key and old style init KSA
//
//	send: myString.encrypt2(firstKey,secondKey)		// uses the new init2 KSA
//
// DISCLAIMER:
//	HENK REINTS HAS WRITTEN THIS SOFWARE FOR HIS OWN USE, AS A HOBBY, WITHOUT ANY COMMERCIAL INTENTIONS.
//	IT IS PROVIDED AS IS, WITHOUT ANY GUARANTEE FOR CORRECTNESS OR USABILITY. USAGE IS AT YOUR OWN RISK.
//	IN NO WAY SHALL HENK REINTS BE LIABLE FOR ANY NEGATIVE CONSEQUENCES OF USING THIS SOFTWARE.
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

String.prototype.hrc4escape	=function()	{return (new HRC4()).escape (this) }

String.prototype.toHex		=function(sep)	{return (new HRC4()).toHex	(this,arguments.length>0?sep:"") }
String.prototype.fromHex	=function()	{return (new HRC4()).fromHex	(this) }
String.prototype.toDec		=function(sep)	{return (new HRC4()).toDec	(this,arguments.length>0?sep:"") }
String.prototype.fromDec	=function()	{return (new HRC4()).fromDec	(this) }
String.prototype.toBase64	=function(wrap)	{return (new HRC4()).toBase64	(this,arguments.length>0?wrap:NaN) }
String.prototype.fromBase64	=function()	{return (new HRC4()).fromBase64	(this) }
String.prototype.toQuotPr	=function()	{return (new HRC4()).toQuotPr	(this) }
String.prototype.fromQuotPr	=function()	{return (new HRC4()).fromQuotPr	(this) }

String.prototype.unicodeToBytes	=function()	{return (new HRC4()).unicodeToBytes (this) }
String.prototype.bytesToUnicode	=function()	{return (new HRC4()).bytesToUnicode (this) }

String.prototype.MD5		=function()	{return (new HRC4()).MD5	(this) }
String.prototype.SHA1		=function()	{return (new HRC4()).SHA1	(this) }
String.prototype.SHA256		=function()	{return (new HRC4()).SHA256	(this) }
String.prototype.FP32		=function()	{return (new HRC4()).FP32	(this) }
String.prototype.FP64		=function()	{return (new HRC4()).FP64	(this) }

String.prototype.HMAC_MD5	=function(key)	{return (new HRC4()).HMAC_MD5	(this,key) }
String.prototype.HMAC_SHA1	=function(key)	{return (new HRC4()).HMAC_SHA1	(this,key) }
String.prototype.HMAC_SHA256	=function(key)	{return (new HRC4()).HMAC_SHA256(this,key) }
String.prototype.HMAC_FP32	=function(key)	{return (new HRC4()).HMAC_FP32	(this,key) }
String.prototype.HMAC_FP64	=function(key)	{return (new HRC4()).HMAC_FP64	(this,key) }

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// below, 'x' can be a direct key String or an existing HRC4 Object Instance;
// 'u' and 'a' are the 'unicode' and 'addmarker' argumenta as used in hrc4.js:
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

String.prototype.cypher		=function(x)	{return (x.constructor==HRC4?x:new HRC4(""+x)).cypher  (this) }
String.prototype.encypher	=function(x)	{return (x.constructor==HRC4?x:new HRC4(""+x)).encypher(this) }
String.prototype.decypher	=function(x)	{return (x.constructor==HRC4?x:new HRC4(""+x)).decypher(this) }
String.prototype.encrypt	=function(x,u,a){return (x.constructor==HRC4?x:new HRC4(""+x)).encrypt (this, u?true:false,a?true:false) }
String.prototype.decrypt	=function(x,u)	{return (x.constructor==HRC4?x:new HRC4(""+x)).decrypt (this, u?true:false) }

String.prototype.cypher2	=function(k1,k2)	{return HRC4.cypher2  (this,k1,k2) }
String.prototype.encypher2	=function(k1,k2)	{return HRC4.encypher2(this,k1,k2) }
String.prototype.decypher2	=function(k1,k2)	{return HRC4.decypher2(this,k1,k2) }
String.prototype.encrypt2	=function(k1,k2,u,a)	{return HRC4.encrypt2 (this,k1,k2, u?true:false,a?true:false) }
String.prototype.decrypt2	=function(k1,k2,u)	{return HRC4.decrypt2 (this,k1,k2, u?true:false) }

// ################################################################################################
// [end of file] hrc4string.js -- Copyright (c) 2008 Henk Reints, http://henk-reints.nl
